      subroutine add_to_list(object_ref,n_obj_left,sky_ref,n_sky_left,
     :   id)
C+------------------------------------------------------------------------------
C
C     Name:   
C        add_to_list
C
C     Invocation:
C        call add_to_list(object_ref,n_obj_left,sky_ref,n_sky_left,id)
C
C     Description:
C        An object or sky patch is added into the appropriate reference
C        list and the relevant counter is incremented.  
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        object_ref:  Integer array (!)
C           Array of reference numbers for objects and fiducials
C        n_obj_left:  Integer (!)
C           Number of objects which are not yet covered by a fibre
C        sky_ref:  Integer array (!)
C           Array of reference numbers of sky patches
C        n_sky_left:  Integer (!)
C           Number of sky patches which are not yet covered by a fibre
C        id:  Integer (>)
C           Reference number of the object to be added into a list.  This
C           should include the sky offset if this is a sky patch.
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        none
C
C     Algorithm:
C        -- If the object reference is zero or is greater than or equal to
C           'alloc_cur' (the standard object reference number for cursor
C           placed fibres) then exit this routine immediately.
C        -- If the object reference is greater numerically than 'alloc_sky'
C           (the standard sky patch reference number offset) then this is
C           a sky patch.  Otherwise it's an object (either program or fiducial)
C        -- Increment the counter to the reference list appropriate for the
C           type of object and put the object reference (minus the offset
C           for sky patches) back into the list.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
C
C     Parameters
C
      integer object_ref(*)
      integer n_obj_left
      integer sky_ref(*)
      integer n_sky_left
      integer id
C
C     If this is a null object or if it is a cursor placed location
C     then escape from here
C
      if ((id .le. 0) .or. (id .ge. alloc_cur)) go to 500
C
C     If the object is a sky, then add it into the sky reference
C
      if (id .gt. alloc_sky) then
         n_sky_left = n_sky_left + 1
         sky_ref(n_sky_left) = id - alloc_sky
C
C     Otherwise, add it into the object reference.
C
      else if (id .gt. 0) then
         n_obj_left = n_obj_left + 1
         object_ref(n_obj_left) = id
      end if
C
C     Exit
C
  500 continue
      end
