#include <stdio.h>
#include <stdlib.h>
#include "af2_par.h"

#ifdef REMOVE_CSUB_UNDERSCORE
void csub_delete_(name,name_length,status)
#else
void csub_delete__(name,name_length,status)
#endif
/*----------------------------------------------------------------------------*/
/*                                                                            */
/*    Name:                                                                   */
/*       csub_delete_                                                         */
/*                                                                            */
/*    Invocation:                                                             */
/*       call csub_delete(name,name_length,status)                            */
/*                                                                            */
/*    Description:                                                            */
/*       Delete a file                                                        */
/*                                                                            */
/*    Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)         */
/*       name:  Char* (>)                                                     */
/*          The FORTRAN character string with the name of the file            */
/*          to be deleted           .                                         */
/*       name_length:  Int* (>)                                               */
/*          The length of the name string                                     */
/*       status:  Int* (!)                                                    */
/*          The global status variable                                        */
/*                                                                            */
/*    Language:                                                               */
/*       ANSI C                                                               */
/*                                                                            */
/*    Non-standard language extensions:                                       */
/*       None                                                                 */
/*                                                                            */
/*    Algorithm:                                                              */
/*       -- Find the last non-blank character in the FORTRAN string and       */
/*          allocate workspace to copy the non-blank bit into.                */
/*       -- Copy the FORTRAN string over and use the intrinsic remove         */
/*          to get rid of the file                                            */
/*       -- Free the workspace and exit                                       */
/*                                                                            */
/*    Authors:                                                                */
/*       (JRL): James R. Lewis -- RGO, Cambridge                              */
/*                                                                            */
/*    History:                                                                */
/*       02 Sep 1996 (JRL):                                                   */
/*          Original version                                                  */
/*                                                                            */
/*----------------------------------------------------------------------------*/

/* Parameters */
char *const name;
int *const name_length;
int *const status;

{

      /* Local variables */
      int i,j;
      char *ptr;

      /* Inherited status */
      if (*status != AF2_OK) return;

      /* Locate the last non-blank character in input FORTRAN string */
      /* Don't forget the the first element is actually 0 not 1 */
      for (i = *name_length - 1; i >= 0 && name[i] == ' '; i--)
         ;

      /* Get some space for a copy of the input string (plus one extra */
      /* for the EOS marker) */
      ptr = (char *)malloc((size_t)(i+2));

      /* If the null pointer came up, then signal an error */
      if (ptr == 0) {
         fprintf(stderr,"Couldn't allocate %d bytes in DELETE\n",i+2);
         *status = AF2_ERR;
         return;
      }

      /* Otherwise copy the string over...*/
      ptr[i+1] = '\0';
      for (; i >= 0; i--)
         ptr[i] = name[i];

      /* Ok, now get the environment name */
      j = remove(ptr);

      /* If the pointer came out null, then signal an error */
      if (j != 0) {
         fprintf(stderr,"No such file as: %s \n",ptr);
         *status = AF2_ERR;
         return;
      }

      /* Free workspace */
      free((void *)ptr);
}
